package App::CRBackup;
BEGIN {
  $App::CRBackup::VERSION = '0.03';
}
use parent qw(File::CRBackup);

__END__
=pod

=head1 NAME

App::CRBackup

=head1 VERSION

version 0.03

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

